/*
 * foc.c
 *
 *  Created on: Aug 19, 2020
 *      Author: a0232121
 */

#include <stdint.h>
#include "inc/hw_types.h"
#include "foc.h"

void motor_init(Motor_t * in)
{
    in->Ls_d = 0.0;
    in->Ls_q = 0.0;
    in->Rs = 1.0;
    in->Phi_e = 0.0;

    in->I_scale = 0.0;
    in->V_scale = 0.0;

    in->dcBus_V = 1.0;       //!< the dcBus value
    in->oneOverDcBus_invV = 1.0;         //!< the DC Bus inverse, 1/V

    in->theta_e = 0.0;         //!< the rotor position
    in->omega_e = 0.0;         //!< the current values

    in->Sine = 0.0;
    in->Cosine = 1.0;

    in->Vff_dq_V[0] = 0.0;          //!< PI_dq FF value for decoupling
    in->Vff_dq_V[1] = 0.0;          //!< PI_dq FF value for decoupling

    // Initialize the PI controllers
    in->pi_id.Kp = 1.0;
    in->pi_id.Ki = 0.0;
    in->pi_id.Ui = 0.0;
    in->pi_id.refValue = 0.0;
    in->pi_id.fbackValue = 0.0;
    in->pi_id.ffwdValue = 0.0;
    in->pi_id.outMax = 1.0;
    in->pi_id.outMin = -1.0;

    in->pi_iq.Kp = 1.0;
    in->pi_iq.Ki = 0.0;
    in->pi_iq.Ui = 0.0;
    in->pi_iq.refValue = 0.0;
    in->pi_iq.fbackValue = 0.0;
    in->pi_iq.ffwdValue = 0.0;
    in->pi_iq.outMax = 1.0;
    in->pi_iq.outMin = -1.0;
}


void FILTER_FO_init(FILTER_FO_Obj* filter, const float32_t bandwidth_Hz, const float32_t sample_freq_Hz)
{
    filter->b0 = TWO_PI * bandwidth_Hz / sample_freq_Hz;
    filter->a1 = (filter->b0 - 1.0);
    filter->b1 = 0.0;
    filter->x1 = 0.0;
    filter->y1 = 0.0;
}


