//#############################################################################
// $TI Release: $
// $Release Date: $
// $Copyright: $
//#############################################################################

/* =================================================================================
File name:        RAMPGEN.H  
===================================================================================*/

#ifndef __RAMPGEN_H__
#define __RAMPGEN_H__

typedef struct { float32_t  Freq; 		  // Input: Ramp frequency (pu)
				 float32_t  StepAngleMax; // Parameter: Maximum step angle (pu)
				 float32_t  Angle;		  // Variable: Step angle (pu)
				 float32_t  Gain;		  // Input: Ramp gain (pu)
				 float32_t  Out;  	 	  // Output: Ramp signal (pu)
				 float32_t  Offset;		  // Input: Ramp offset (pu)
	  	  	   } RAMPGEN;	            

/*------------------------------------------------------------------------------
      Object Initializers
------------------------------------------------------------------------------*/                       
#define RAMPGEN_DEFAULTS { \
        0, /* Freq */ \
        0, /* StepAngleMax */ \
        0, /* Angle */ \
        1, /* Gain */ \
        0, /* Out */ \
        1  /* Offset */ \
    }

/*------------------------------------------------------------------------------
	RAMP(Sawtooh) Generator Macro Definition
------------------------------------------------------------------------------*/                                               

static inline void fclRampGen(RAMPGEN * in)
{
	// Compute the angle rate
	in->Angle += in->StepAngleMax * in->Freq;

	// Saturate the angle rate within (-1,1)
	if(in->Angle > 1.0)
	{
		in->Angle -= 1.0;
	}
	else if(in->Angle < -1.0)
	{
		in->Angle += 1.0;
	}

	in->Out = in->Angle;
}


#define RG_MACRO(v)									\
													\
	/* Compute the angle rate */					\
	v.Angle += _IQmpy(v.StepAngleMax,v.Freq);		\
													\
    /* Saturate the angle rate within (-1,1) */		\
	if (v.Angle>_IQ(1.0))							\
		v.Angle -= _IQ(1.0);						\
	else if (v.Angle<_IQ(-1.0))						\
		v.Angle += _IQ(1.0);						\
		v.Out=v.Angle;

   /* Use the code snippet below if gain/offset needed.													\
	v.Out = _IQmpy(v.Angle,v.Gain) + v.Offset;		\
	if (v.Out>_IQ(1.0))								\
		v.Out -= _IQ(1.0);							\
	else if (v.Out<_IQ(-1.0))						\
		v.Out += _IQ(1.0);
*/

#define RG_INIT_MACRO(v, fb, Ys)                  \
    v.Angle=0.0;                                  \
    v.Freq=0;                                     \
    v.StepAngleMax=fb*Ts;                         \
    v.Out=0.0;                                    \

#endif // __RAMPGEN_H__
